/*
 * Copyright (C) 2011 SHARP Corporation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jp.co.sharp.android;

import android.app.Activity;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;
import android.content.ActivityNotFoundException;
import android.content.Intent;
import java.util.Calendar;

/**
 * ワンセグの拡張IFを使用するためのサンプルである。
 * 以下のソースを使用して
 * ワンセグテレビの起動、予約登録処理、録画/視聴予約画面の起動
 * を行うことができる。
 */
public class SampleOneseg extends Activity {
    /** Called when the activity is first created. */
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);

        Button start = (Button)findViewById(R.id.start);
        start.setOnClickListener(new View.OnClickListener(){
            @Override
            public void onClick(View v) {
                /* ***** ワンセグテレビの起動 ***********************************************/
                Intent newIntent = new Intent();
                // ワンセグテレビを起動するアクションを設定
                newIntent.setAction("jp.co.sharp.android.oneseg.view.action.RUN");
                // 起動したときのワンセグのチャンネルを指定
                newIntent.putExtra("jp.co.sharp.android.oneseg.EXTRA_KEY_CHANNEL_NO", 20);
                
                try {
                    // インテントを投げる
                    startActivity(newIntent);
                    // ワンセグ起動をToastでお知らせ
                    Toast.makeText(v.getContext(), "Start Oneseg : Channnel 20", Toast.LENGTH_LONG).show();
                    finish();
                } catch (ActivityNotFoundException e){
                    // 非対応をToastでお知らせ
                    Toast.makeText(v.getContext(), "not support.", Toast.LENGTH_SHORT).show();
                }
                /* ************************************************************************** */
            }
        });        /* ***** 予約登録処理 *******************************************************
        // 現在の日時をシステムから取得する
        Calendar start = Calendar.getInstance();
        Calendar end = Calendar.getInstance();
        // 予約の開始日時を設定する
        start.add(Calendar.MINUTE, 10);
        // 予約の終了日時を設定する
        end.add(Calendar.MINUTE, 20);

        Intent newIntent = new Intent();
        // ワンセグテレビを予約するアクションを設定
        newIntent.setAction("jp.co.sharp.android.oneseg.reservation.action.INSERT");
        // 予約種別を設定  0：視聴予約、1：録画予約
        newIntent.putExtra("jp.co.sharp.android.oneseg.EXTRA_KEY_RESERVATION_TYPE", 1);
        // 起動したときのワンセグのチャンネルを指定
        newIntent.putExtra("jp.co.sharp.android.oneseg.EXTRA_KEY_RESERVATION_CHANNEL_NO", 20);
        // 予約の開始日時を設定する
        newIntent.putExtra("jp.co.sharp.android.oneseg.EXTRA_KEY_RESERVATION_START_DATE", start.getTimeInMillis());
        // 予約の終了日時を設定する
        newIntent.putExtra("jp.co.sharp.android.oneseg.EXTRA_KEY_RESERVATION_END_DATE", end.getTimeInMillis());
        // 番組名称を設定する
        newIntent.putExtra("jp.co.sharp.android.oneseg.EXTRA_KEY_RESERVATION_PROGRAM_NAME", "番組名称");
        // インテントを投げる
        startActivity(newIntent);
        finish();
        * *************************************************************************** */

        /* ***** 録画/視聴予約画面の起動 ********************************************
        Intent newIntent = new Intent();
        // ワンセグ録画/視聴予約画面を起動するアクションを設定
        newIntent.setAction("jp.co.sharp.android.oneseg.reservation.action.VIEW");
        // インテントを投げる
        startActivity(newIntent);
        finish();
        * *************************************************************************** */


    }
}